@@ -16,7 +16,7 @@ import ldap
 
 import sys
 
-sys.getrecursionlimit(10000)
+sys.setrecursionlimit(10000)
 
 __all__ = ["Position", "Department", "SystemAccount", "User", "App", "AppGroup"]
 
